ResponsiveHelper class

Constructors

ResponsiveHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

responsiveFontSize(BuildContext context, double fontSize) double
responsiveHeight(BuildContext context, double height) double
responsivePadding(BuildContext context, {double left = 0, double top = 0, double right = 0, double bottom = 0}) EdgeInsets
responsiveWidth(BuildContext context, double width) double
screenHeight(BuildContext context) double
screenWidth(BuildContext context) double

Constants

baseHeight → const double
baseWidth → const double